@@ -9,7 +9,7 @@ use gitext::{
     changelog::ChangeLog,
     commands::shared::{load_config, set_current_dir_from_arg},
     git::{git_add, git_commit, git_push_follow_tags, git_set_tag, git_status_porcelain},
-    version::{bump_repo_version, exec_bump_commands},
+    version::{exec_bump_commands, get_repo_next_version},
 };
 
 /// Release command
@@ -28,6 +28,9 @@ pub struct Cli {
     /// If set, commits and tags are pushed
     #[clap(long, short)]
     pub push: bool,
+    /// If set, the RELEASENOTES.md file is not generated
+    #[clap(long)]
+    pub no_release_notes: bool,
 }
 
 fn main() {
@@ -90,7 +93,7 @@ fn main() {
         }
     };
 
-    let (next_version, prev_version) = match bump_repo_version(&config) {
+    let (next_version, prev_version) = match get_repo_next_version(&config) {
         Ok((next_version, prev_version)) => (next_version, prev_version),
         Err(err) => {
             term.write_line(style(format!("✗ {err}")).red().to_string().as_str())
@@ -99,14 +102,15 @@ fn main() {
         }
     };
 
-    let changelog_str = match changelog.generate(&config, &next_version.to_string()) {
-        Ok(s) => s,
-        Err(err) => {
-            term.write_line(style(format!("✗ {err}")).red().to_string().as_str())
-                .unwrap();
-            exit(1);
-        }
-    };
+    let (changelog_str, releasenotes_str) =
+        match changelog.generate(&config, &next_version.to_string()) {
+            Ok(s) => s,
+            Err(err) => {
+                term.write_line(style(format!("✗ {err}")).red().to_string().as_str())
+                    .unwrap();
+                exit(1);
+            }
+        };
 
     if !args.commit {
         term.write_line(
@@ -157,6 +161,27 @@ fn main() {
         }
     }
 
+    if !args.no_release_notes {
+        match fs::write(cwd.join("RELEASENOTES.md"), releasenotes_str) {
+            Ok(_) => {
+                term.write_line(
+                    format!(
+                        "{} {}",
+                        style("✔").green(),
+                        style("Generated release notes").bold()
+                    )
+                    .as_str(),
+                )
+                .unwrap();
+            }
+            Err(err) => {
+                term.write_line(style(format!("✗ {err}")).red().to_string().as_str())
+                    .unwrap();
+                exit(1);
+            }
+        }
+    }
+
     // 3. Bump the package versions
     match exec_bump_commands(&config, &next_version.to_string()) {
         Ok(exec_commands) => {
